(* ::Package:: *)

(* :Title: LightFrontSpinors *)
(* :Author: Yang Li *)
(* :Email: leeyoung@iastate.edu *)


(* :Summary: This package provides a particular representation of the 
light-front Dirac spinors *)


(* :Version: 0.1 *)
(* :History:  *)
(* :Mathematica version: 10.0 for Linux *)
(* :Context: LightFrontSpinors`LightFrontSpinors` *)

(* :Welcome message *)
Print["Mathematica package LightFrontSpinors"];
Print["Author: Yang Li, <leeyoung@iastate.edu>"];
Print["Type ListOfVariables[] to see the list of light-front spinors."];
Print["Type ListOfFunctions[] to see the list of utility functions."];
Print["Type ListOfRules[] to see the list of rules."];
Print[DateString[]];

BeginPackage["LightFrontSpinors`LightFrontSpinors`"];

(* :Variables *)

(* :Usage Message *)
ListOfVariables::usage = "ListOfVariables[] shows the list of light-front spinors defined in this package."
ListOfFunctions::usage = "ListOfFunctions[] shows the list of utility functions defined in this package."
ListOfRules::usage = "ListOfRules[] shows the list of rules defined in this package."

DisplayGamma::usage = "DisplayGamma[] displays the gamma matrices \!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(5\)]\) in matrix form."

DisplayGammaOnLightFront::usage = "DisplayGammaOnLightFront[] shows the gamma matrices \!\(\*SuperscriptBox[\(\[Gamma]\), \(+\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(-\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(L\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(R\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(5\)]\) in matrix form."

Slashed::usage = "Slashed[\(\*SuperscriptBox[\(p\), \(+\)]\), \(\*SubscriptBox[\(p\), \(x\)]\), \(\*SubscriptBox[\(p\), \(y\)]\), m] gives the Feynman slashed symbols \\slashed{p}."

Gamma0::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\)"
Gamma1::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\)"
Gamma2::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\)"
Gamma3::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\)"
GammaP::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(+\)]\) = \!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\) + \!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\)"
GammaM::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(-\)]\) = \!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\) - \!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\)"
GammaL::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(L\)]\) = \!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\) - \[ImaginaryI] \!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\)"
GammaR::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(R\)]\) = \!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\) + \[ImaginaryI] \!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\)"
Gamma5::usage = "4 \[Times] 4 gamma matrix \!\(\*SuperscriptBox[\(\[Gamma]\), \(5\)]\)"
GammaMatrices::usage = "GammaMatrices collects all four gamma matrices in a list { \!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\), \!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\) }"

u::usage = "u[s, \!\(\*SuperscriptBox[\(p\), \(+\)]\), \!\(\*SubscriptBox[\(p\), \(x\)]\), \!\(\*SubscriptBox[\(p\), \(y\)]\), m] gives the bilinear spinor \!\(\*SubscriptBox[\(u\), \(s\)]\)(p). s=+1,-1."

v::usage = "v[s, \!\(\*SuperscriptBox[\(p\), \(+\)]\), \!\(\*SubscriptBox[\(p\), \(x\)]\), \!\(\*SubscriptBox[\(p\), \(y\)]\), m] gives the bilinear spinor \!\(\*SubscriptBox[\(v\), \(s\)]\)(p). s=+1,-1."

ubar::usage = "ubar[s, \!\(\*SuperscriptBox[\(p\), \(+\)]\), \!\(\*SubscriptBox[\(p\), \(x\)]\), \!\(\*SubscriptBox[\(p\), \(y\)]\), m] gives the bilinear spinor \!\(\*SubscriptBox[\(\*OverscriptBox[\(u\), \(_\)]\), \(s\)]\)(p). s=+1,-1."

vbar::usage = "vbar[s, \!\(\*SuperscriptBox[\(p\), \(+\)]\), \!\(\*SubscriptBox[\(p\), \(x\)]\), \!\(\*SubscriptBox[\(p\), \(y\)]\), m] gives the bilinear spinor \!\(\*SubscriptBox[\(\*OverscriptBox[\(v\), \(_\)]\), \(s\)]\)(p). s=+1,-1."

displayconjugate::usage = "displayconjugate provides rules to simply the displaying of complex conjugate."

displaycomplex::usage = "displayconjugate provides rules to simply the displaying of complex numbers."


(* :Error Messages *)

Begin["`Private`"];

(* :Documentation *)
ListOfVariables[] := Print[
"Gamma0, Gamma1, Gamma2, Gamma3, Gamma5, GammaMatrices, GammaP, GammaM, GammaL, GammaR."
]

ListOfFunctions[] := Print[
"DisplayGamma[], DisplayGammaOnLightFront[], Slashed[], u, v, ubar, vbar."
]

ListOfRules[] := Print[
"displayconjugate, displaycomplex."
]

(* :Dirac gamma matrices *)
Gamma0 = {{0, 0, -I, 0}, {0, 0, 0, -I}, {I, 0, 0, 0}, {0, I, 0, 0}};
Gamma1 = {{0, -1, 0, 0}, {1, 0, 0, 0}, {0, 0, 0, 1}, {0, 0, -1, 0}};
Gamma2 = {{0, I, 0, 0}, {I, 0, 0, 0}, {0, 0, 0, -I}, {0, 0, -I, 0}};
Gamma3 = {{0, 0, I, 0}, {0, 0, 0, I}, {I, 0, 0, 0}, {0, I, 0, 0}};
Gamma5 = {{1, 0, 0, 0}, {0, -1, 0, 0}, {0, 0, -1, 0}, {0, 0, 0, 1}};

GammaMatrices = {Gamma0, Gamma1, Gamma2, Gamma3};

DisplayGamma[] := Row[{"\!\(\*SuperscriptBox[\(\[Gamma]\), \(0\)]\)=", Gamma0 // 
   MatrixForm, 
  ",\!\(\*SuperscriptBox[\(\[Gamma]\), \(1\)]\)=", Gamma1 // 
   MatrixForm, 
  ",\!\(\*SuperscriptBox[\(\[Gamma]\), \(2\)]\)=", Gamma2 // 
   MatrixForm, 
  ",\!\(\*SuperscriptBox[\(\[Gamma]\), \(3\)]\)=", Gamma3 // 
   MatrixForm, 
  ",\!\(\*SuperscriptBox[\(\[Gamma]\), \(5\)]\)=", Gamma5 // 
   MatrixForm}]

(* :light-front gamma matrices *)
(* GammaP = Gamma0 + Gamma3, GammaM = Gamma0 - Gamma3, GammaL = Gamma1 - I*Gamma2, GammaR = Gamma1 + I*Gamma2 *)
GammaP = {{0, 0, 0, 0}, {0, 0, 0, 0}, {2 I, 0, 0, 0}, {0, 2 I, 0, 0}};
GammaM = {{0, 0, -2 I, 0}, {0, 0, 0, -2 I}, {0, 0, 0, 0}, {0, 0, 0, 0}};
GammaL = {{0, 0, 0, 0}, {2, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, -2, 0}};
GammaR = {{0, -2, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 2}, {0, 0, 0, 0}};

DisplayGammaOnLightFront[] := Row[{"\!\(\*SuperscriptBox[\(\[Gamma]\), \(+\)]\)=", GammaP // 
   MatrixForm, 
  ", \!\(\*SuperscriptBox[\(\[Gamma]\), \(-\)]\)=", GammaM // 
   MatrixForm, 
  ", \!\(\*SuperscriptBox[\(\[Gamma]\), \(L\)]\)=", GammaL // 
   MatrixForm, 
  ", \!\(\*SuperscriptBox[\(\[Gamma]\), \(R\)]\)=", GammaR // 
   MatrixForm, 
  ", \!\(\*SuperscriptBox[\(\[Gamma]\), \(5\)]\)=", Gamma5 // 
   MatrixForm}]
   
(* parity matrix \[Beta] = Gamma^0: Beta= {{0, 0, -I, 0}, {0, 0, 0, -I}, {I, 0, 0, 0}, {0, I, 0, 0}}; *)

(* :Feynman's slash notation *)
Slashed[p_List] := GammaMatrices[[1]]*p[[1]] - GammaMatrices[[2]]*p[[2]] - GammaMatrices[[3]]*p[[3]] - GammaMatrices[[4]]*p[[4]]

Slashed[x_, px_, py_, mf_] := 1/2*(px*px + py*py + mf*mf)/x*GammaP + x*GammaM/2 - px*Gamma1 - py*Gamma2


(* :Bilinear spinors *)
u[s_, x_, px_, py_, mf_] := (Slashed[x, px, py, mf] + mf*IdentityMatrix[4]).GammaP.{(1+s)/2,(1-s)/2,0,0}/(2*Sqrt[x])

v[s_, x_, px_, py_, mf_] := (Slashed[x, px, py, mf] - mf*IdentityMatrix[4]).GammaP.{(1-s)/2,(1+s)/2,0,0}/(2*Sqrt[x])

ubar[s_, x_, px_, py_, mf_] := Conjugate[u[s, x, px, py, mf]].Gamma0

vbar[s_, x_, px_, py_, mf_] := Conjugate[v[s, x, px, py, mf]].Gamma0


(* :rules to simplify complex variables *)

displayconjugate = {Conjugate[x_] -> \!\(\*SuperscriptBox[\(x\), \("\<*\>"\)]\)}

displaycomplex = {Re[x_] + I Im[x_] -> x, Re[x_] - I Im[x_] -> Conjugate[x], 
  I Re[x_] + Im[x_] -> I*Conjugate[x], I Re[x_] - Im[x_] -> I * x, 
  I Im[x_] - Re[x_] -> -Conjugate[x], -I Im[x_] - Re[x_] -> -x}


End[];

EndPackage[];
